==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Перевірку майже завершено. Дякуємо вам за терпіння</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Приготування</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Виконано перевірку щодо певних помилок</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Перейти до стільниці</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Ласкаво просимо, система успішно оновлена</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Поточна версія:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Переглянути журнал</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Успішно оновлено</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Ваш комп&apos;ютер невдовзі буде перезавантажено %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Ваш комп&apos;ютер невдовзі буде вимкнено %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Помилка під час спроби автоматичного перезавантаження. Будь ласка, перезавантажте ваш пристрій вручну.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Помилка під час спроби автоматичного вимикання. Будь ласка, вимкніть ваш пристрій вручну.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Приховати журнал</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Помилка оновлення</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Невідома помилка</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Не вдалося створити резервну копію</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Не вдалося виконати резервне копіювання системи. Якщо продовжити процедуру оновлення, ви не зможете повернутися до попереднього стану системи пізніше.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Недостатньо вільного місця на диску. Будь ласка, звільніть місце і повторіть спробу.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Не вдалося встановити зв&apos;язок із службами резервного копіювання. Будь ласка, перевірте зв&apos;язок і повторіть спробу</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Не вдалося встановити зв&apos;язок із службами оновлення. Будь ласка, перевірте зв&apos;язок і повторіть спробу</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Помилка у залежностях</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Помилка DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Повторити спробу копіювання</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Перервати</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Перейти до оновлення</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Перейти до стільниці</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Готуємося до оновлень…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Не виконуйте примусового вимикання або знеструмлення комп&apos;ютера при встановленні оновлень. Якщо ви так зробите, системі може бути завдано шкоди.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.31.tar.xz: BUILD/src/dde-update/translations/dde-update_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Перевірку майже завершено. Дякуємо вам за терпіння</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Приготування</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Виконано перевірку щодо певних помилок</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Перейти до стільниці</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Ласкаво просимо, система успішно оновлена</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Поточна версія:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Успішно оновлено</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Ваш комп&apos;ютер невдовзі буде перезавантажено %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Ваш комп&apos;ютер невдовзі буде вимкнено %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Помилка під час спроби автоматичного перезавантаження. Будь ласка, перезавантажте ваш пристрій вручну.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Помилка під час спроби автоматичного вимикання. Будь ласка, вимкніть ваш пристрій вручну.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Переглянути журнал оновлення</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Згорнути журнали оновлення</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Журнал було експортовано до стільниці</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Не вдалося експортувати журнал. Будь ласка, повторіть спробу</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Помилка оновлення</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Невідома помилка</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Не вдалося створити резервну копію</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Не вдалося виконати резервне копіювання системи. Якщо продовжити процедуру оновлення, ви не зможете повернутися до попереднього стану системи пізніше.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Недостатньо вільного місця на диску. Будь ласка, звільніть місце і повторіть спробу.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Не вдалося встановити зв&apos;язок із службами резервного копіювання. Будь ласка, перевірте зв&apos;язок і повторіть спробу</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Не вдалося встановити зв&apos;язок із службами оновлення. Будь ласка, перевірте зв&apos;язок і повторіть спробу</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Помилка у залежностях</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Помилка DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Повторити спробу копіювання</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Перервати</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Перейти до оновлення</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Перейти до стільниці</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Готуємося до оновлень…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Не виконуйте примусового вимикання або знеструмлення комп&apos;ютера при встановленні оновлень. Якщо ви так зробите, системі може бути завдано шкоди.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Переглянути журнал оновлення</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Згорнути журнали оновлення</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>журнал_оновлення</translation>
    </message>
</context>
</TS>
